const apiBaseUrl = "https://api.hyperapps.in/api/v2";

// When the page is loaded, fetch order details
document.addEventListener("DOMContentLoaded", async () => {
  const params = new URLSearchParams(window.location.search);
  const orderId = params.get("orderId");

  if (orderId) {
    await fetchOrderDetails(orderId);
    await fetchFulfillmentDetails(orderId);
  } else {
    alert("Order ID not provided!");
  }
});

// Fetch order details using the orderId
async function fetchOrderDetails(orderId) {
  try {
    const order = await fetchData("order", { id_eq: orderId });
    if (order.length > 0) {
      populateOrderDetails(order[0]);
      fetchAdditionalDetails(order[0]); // Fetch related data for the order
    } else {
      alert("Order not found!");
    }
  } catch (error) {
    console.error("Error fetching order details:", error);
  }
}

// Fetch related customer, restaurant, and delivery details
async function fetchAdditionalDetails(order) {
  try {
    const customerPromise = fetchData("customer", { id_eq: order.customerId });
    const restaurantPromise = fetchData("restaurant", order.restaurantId, true);
    const deliveryPromise = order.deliveryDetails?.addressId
      ? fetchData("address", order.deliveryDetails.addressId, true)
      : Promise.resolve([]); 

    const [customer, restaurant, address] = await Promise.all([
      customerPromise,
      restaurantPromise,
      deliveryPromise,
    ]);

    if (restaurant && restaurant.length > 0) {
      populateRestaurantDetails(restaurant[0]);
    }

    if (customer.length > 0) populateCustomerDetails(customer[0]);
    if (address.length > 0) populateDeliveryDetails(address[0]);
  } catch (error) {
    console.error("Error fetching additional details:", error);
  }
}

// Fetch Fulfillment Details
async function fetchFulfillmentDetails(orderId) {
  try {
    const fulfillmentResponse = await fetchData("delivery", { orderId_eq: orderId });
    
    if (fulfillmentResponse.length > 0 && fulfillmentResponse[0]?.fulfillment) {
      populateFulfillmentDetails(fulfillmentResponse[0].fulfillment);
      document.getElementById("fulfillmentDetails").style.display = "block";
    } else {
      console.warn("No fulfillment details found.");
      document.getElementById("fulfillmentDetails").style.display = "none";
    }
  } catch (error) {
    console.error("Error fetching fulfillment details:", error);
    document.getElementById("fulfillmentDetails").style.display = "none";
  }
}

// Populate order details in the DOM
function populateOrderDetails(order) {
  document.getElementById("orderId").textContent = order.id;
  document.getElementById("orderStatus").textContent = order.status;
  document.getElementById("orderCreatedAt").textContent = formatDate(order.createdAt);
  document.getElementById("orderUpdatedAt").textContent = formatDate(order.updatedAt);
  document.getElementById("orderTotal").textContent = `₹${order.grandTotalAmount}`;
  document.getElementById("orderInstructions").textContent = order.specialInstructions || "None";

  const actionButtons = document.getElementById("actionButtons");
  actionButtons.innerHTML = ""; // Clear previous buttons

  if (order.status === 'CREATED' || order.status === 'PAYMENT_PENDING') {
    const markAsDeliveredBtn = createActionButton("Mark as Delivered", "blue", () => markAsDelivered(order.id));
    const cancelOrderBtn = createActionButton("Cancel Order", "red", () => cancelOrder(order.id));
    const allocateOrderBtn = createActionButton("Allocate Order", "orange", () => allocateOrder(order.id));

    actionButtons.appendChild(markAsDeliveredBtn);
    actionButtons.appendChild(cancelOrderBtn);
    actionButtons.appendChild(allocateOrderBtn);
  }

  const orderItemsBody = document.getElementById("orderItemsBody");
  order.orderItems.forEach((item) => {
    const row = document.createElement("tr");
    const taxes = item.orderItemTax
      ? item.orderItemTax.map((tax) => `₹${tax.amount}`).join(", ")
      : "N/A";
    row.innerHTML = `
      <td>${item.name}</td>
      <td>${item.quantity}</td>
      <td>₹${item.price}</td>
      <td>${taxes}</td>
    `;
    orderItemsBody.appendChild(row);
  });
}

// Populate customer details in the DOM
function populateCustomerDetails(customer) {
  document.getElementById("customerName").textContent = customer.name || "N/A";
  document.getElementById("customerMobile").textContent = customer.mobile || "N/A";
}

// Populate restaurant details in the DOM
function populateRestaurantDetails(restaurant) {
  if (!restaurant) {
    console.error("Restaurant data is not available.");
    return;
  }
  document.getElementById("restaurantName").textContent = restaurant.restaurantName || "N/A";
  document.getElementById("restaurantContact").textContent = restaurant.contact || "N/A";
  document.getElementById("restaurantAddress").textContent = restaurant.address || "N/A";
}

// Populate delivery details in the DOM
function populateDeliveryDetails(address) {
  document.getElementById("deliveryAddress1").textContent = address.addressOne || "N/A";
  document.getElementById("deliveryAddress2").textContent = address.addressTwo || "N/A";
  document.getElementById("deliveryCity").textContent = address.city || "N/A";
  document.getElementById("deliveryState").textContent = address.state || "N/A";
  document.getElementById("deliveryCountry").textContent = address.country || "N/A";
  document.getElementById("deliveryPincode").textContent = address.pincode || "N/A";
}

// Populate Fulfillment Details in the DOM
function populateFulfillmentDetails(fulfillment) {
  const fulfillmentDetailsSection = document.getElementById("fulfillmentDetails");

  if (fulfillment) {
    document.getElementById("fulfillmentStatus").textContent = fulfillment.status || "N/A";
    document.getElementById("fulfillmentChannel").textContent = fulfillment.channel?.name || "N/A";
    document.getElementById("fulfillmentRiderName").textContent = fulfillment.rider?.name || "N/A";
    document.getElementById("fulfillmentRiderMobile").textContent = fulfillment.rider?.mobile || "N/A";
    document.getElementById("fulfillmentPickupTime").textContent = formatDate(fulfillment.pickup?.timestamp) || "N/A";
    document.getElementById("fulfillmentDeliveryTime").textContent = formatDate(fulfillment.drop?.timestamp) || "N/A";
    document.getElementById("fulfillmentDeliveryCharge").textContent = `₹${fulfillment.deliveryCharge || 0}`;

    // Add Tracking Link
    const trackingLinkElement = document.getElementById("fulfillmentTrackingLink");
    if (fulfillment.trackCode) {
      trackingLinkElement.href = `https://t.pidge.in/?t=${fulfillment.trackCode}`;
      trackingLinkElement.textContent = "Track Order";
      trackingLinkElement.style.display = "inline";
    } else {
      trackingLinkElement.href = "#";
      trackingLinkElement.textContent = "No Tracking Available";
      trackingLinkElement.style.display = "none";
    }

    // Populate Fulfillment Logs
    if (fulfillment.logs && fulfillment.logs.length > 0) {
      populateFulfillmentLogs(fulfillment.logs);
    } else {
      document.getElementById("fulfillmentLogs").innerHTML = "<p>No logs available.</p>";
    }

    // Show fulfillment section
    fulfillmentDetailsSection.style.display = "block";
  } else {
    // Hide Fulfillment Details (and Logs automatically)
    fulfillmentDetailsSection.style.display = "none";
  }
}

// Populate Fulfillment Logs in a Horizontal Timeline
function populateFulfillmentLogs(logs) {
  const timeline = document.getElementById("fulfillmentLogs");
  timeline.innerHTML = ""; // Clear existing logs

  logs.forEach((log) => {
    const logItem = document.createElement("div");
    logItem.className = "timeline-item";

    const timestamp = log.timestamp ? formatTimestamp(log.timestamp) : "N/A";
    const status = log.status || "Unknown Status";
    const rider = log.rider?.name ? `Rider: ${log.rider.name}` : "No Rider Info";

    logItem.innerHTML = `
      <div class="timestamp">${timestamp}</div>
      <div class="status">${status}</div>
      <div class="rider">${rider}</div>
    `;

    timeline.appendChild(logItem);
  });
}

// Reusable fetch function to get data from the API
async function fetchData(endpoint, queryParams = {}, isPathBased = false) {
  let url;

  if (isPathBased) {
    url = `${apiBaseUrl}/${endpoint}/${queryParams}`; 
  } else {
    url = `${apiBaseUrl}/${endpoint}?${new URLSearchParams(queryParams)}`;
  }

  const response = await fetch(url);
  if (response.ok) {
    const data = await response.json();
    return data.data;
  } else {
    throw new Error(`Failed to fetch data from ${url}`);
  }
}

function createActionButton(text, color, clickHandler) {
  const button = document.createElement("button");
  button.className = "btn btn-sm me-2"; // Add margin
  button.style.backgroundColor = color;
  button.style.color = "white";
  button.textContent = text;
  button.addEventListener("click", clickHandler);
  return button;
}

function markAsDelivered(orderId) {
  if (confirm("Are you sure you want to mark this order as delivered?")) {
    fetch(`${apiBaseUrl}/order/${orderId}`, {
      method: "PATCH",
      headers: {
        "Content-Type": "application/json",
      },
      body: JSON.stringify({
        status: "DELIVERED", // Change status to DELIVERED
      }),
    })
      .then(response => response.json())
      .then(() => {
        alert("Order mark as DELIVERED successfully.");
        location.reload(); // Reload the page to reflect the changes
            })
            .catch(error => {
                console.error("Error marking order as delivered:", error);
                alert("Failed to mark order as delivered. Please try again later."); // Alert the user about the error
            });
  }
}

function cancelOrder(orderId) {
  if (confirm("Are you sure you want to cancel this order?")) {
    fetch(`${apiBaseUrl}/order/${orderId}`, {
      method: "PATCH",
      headers: {
        "Content-Type": "application/json",
      },
      body: JSON.stringify({
        status: "CANCELLED", // Change status to CANCELLED
      }),
    })
      .then(response => response.json())
      .then(() => {
        alert("Order cancelled successfully.");
        location.reload(); // Reload the page to reflect the changes
              })
      .catch(error => console.error("Error cancelling order:", error));
  }
}

function allocateOrder(orderId) {
  if (confirm("Are you sure you want to allocate this order?")) {
    fetch(`${apiBaseUrl}/order/${orderId}`, {
      method: "PATCH",
      headers: {
        "Content-Type": "application/json",
      },
      body: JSON.stringify({
        status: "ALLOCATED", // Change status to ALLOCATED (or whatever status you use for allocated orders)
      }),
    })
      .then(response => response.json())
      .then(() => {
        alert("Order allocated successfully.");
        fetchOrders(); // Refresh the orders table
      })
      .catch(error => console.error("Error allocating order:", error));
  }
}







